@@ -1,8 +1,9 @@
-import requests
 import json
 import os
 from abc import abstractmethod
 
+import requests
+
 
 class mDastBase:
     def __init__(self, base_url):
@@ -79,32 +80,29 @@ class mDastBase:
                             headers=self.headers,
                             verify=False)
 
-    def create_user(self, org_id, user_data, is_admin):
+    def create_user(self, org_id, user_data, role):
         data = {
             'username': user_data['username'],
             'password': user_data['password'],
-            'is_admin': is_admin
+            'role': role
         }
         return requests.post(f'{self.url}/organizations/{org_id}/users/',
                              headers=self.headers,
                              data=json.dumps(data),
                              verify=False)
 
-    def create_user_by_superadmin(self, user_id, username, org_id, is_admin, is_active, change_password,
+    def create_user_by_superadmin(self, user_id, username, org_id, role, is_active, change_password,
                                   accepted_eula, accepted_confidential):
         data = {
             'username': username,
-            'is_admin': is_admin,
+            'role': role,
             'is_active': is_active,
             'change_password': change_password,
             'org_id': org_id,
             'accepted_eula': accepted_eula,
             'accepted_confidential': accepted_confidential
         }
-        return requests.put(f'{self.url}/users/{user_id}/',
-                            headers=self.headers,
-                            data=json.dumps(data),
-                            verify=False)
+        return requests.put(f'{self.url}/users/{user_id}/', headers=self.headers, data=json.dumps(data), verify=False)
 
     def delete_user(self, user_id):
         return requests.delete(f'{self.url}/users/{user_id}/',
@@ -120,19 +118,16 @@ class mDastBase:
                               data=json.dumps(data),
                               verify=False)
 
-    def patch_user(self, user_id, username, is_admin, is_active, change_password, accepted_eula, accepted_confidential):
+    def patch_user(self, user_id, username, role, is_active, change_password, accepted_eula, accepted_confidential):
         data = {
             'username': username,
-            'is_admin': is_admin,
+            'role': role,
             'is_active': is_active,
             'change_password': change_password,
             'accepted_eula': accepted_eula,
             'accepted_confidential': accepted_confidential
         }
-        return requests.patch(f'{self.url}/users/{user_id}/',
-                              headers=self.headers,
-                              data=json.dumps(data),
-                              verify=False)
+        return requests.patch(f'{self.url}/users/{user_id}/', headers=self.headers, data=json.dumps(data), verify=False)
 
     def accept_agreements(self, accept_eula, accept_confidential):
         data = {
@@ -239,6 +234,21 @@ class mDastBase:
                             headers=self.headers,
                             verify=False)
 
+    def get_all_started_scans_by_org_id(self, org_id):
+        return requests.get(f'{self.url}/organizations/{org_id}/dasts/?state=2&ordering=state&page_size=10000',
+                            headers=self.headers,
+                            verify=False)
+
+    def get_all_created_scans_by_org_id(self, org_id):
+        return requests.get(f'{self.url}/organizations/{org_id}/dasts/?state=0&ordering=state&page_size=10000',
+                            headers=self.headers,
+                            verify=False)
+
+    def get_all_scans_by_org_id_filter_profile(self, org_id, profile_id):
+        return requests.get(f'{self.url}/organizations/{org_id}/dasts/?profile={profile_id}',
+                            headers=self.headers,
+                            verify=False)
+
     def get_scan_info(self, scan_id):
         return requests.get(f'{self.url}/dasts/{scan_id}/',
                             headers=self.headers,
@@ -319,6 +329,17 @@ class mDastBase:
                              data=json.dumps(data),
                              verify=False)
 
+    def create_manual_scan_autocreate_profile(self, app_id, arch_id):
+        data = {
+            'application_id': app_id,
+            'architecture_id': arch_id,
+            'type': 0
+        }
+        return requests.post(f'{self.url}/organizations/{self.current_context["company"]}/dasts/',
+                             headers=self.headers,
+                             data=json.dumps(data),
+                             verify=False)
+
     def create_auto_scan(self, profile_id, app_id, arch_id, test_case_id):
         data = {
             'profile_id': profile_id,
@@ -557,3 +578,10 @@ class mDastBase:
                             headers=self.headers,
                             verify=False)
         return logs
+
+    def check_app_md5(self, org_id, md5):
+        resp = requests.get(f'{self.url}/organizations/{org_id}/applications/?md5={md5}',
+                            allow_redirects=True,
+                            headers=self.headers,
+                            verify=False)
+        return resp
